#
# lxc: linux Container library
#
# (C) Copyright IBM Corp. 2007, 2008
# (C) ALT Linux Team 2009-2021
#
# Authors:
# Daniel Lezcano <dlezcano at fr.ibm.com>
# Denis Pynkin <dans at altlinux.org>
# Vladimir D. Seleznev <vseleznv at altlinux.org>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#
# Spec file adapted for ALT Linux.

%define sover 1
%def_with systemd

# Skip automatic dependency to optional lsb scripts
%add_findreq_skiplist %_initdir/*

# Needed to disable auto requirements from distro templates
%add_findreq_skiplist %_datadir/lxc/*

# Do not need to check
%add_findreq_skiplist %_libexecdir/lxc/lxc-apparmor-load
%add_findreq_skiplist %_libexecdir/lxc/lxc-net

Name: lxc
Version: 4.0.10
Release: alt1

Summary: Linux Containers

License: LGPL-2.1-or-later
Group: System/Configuration/Other
Url: https://linuxcontainers.org/

VCS: https://github.com/lxc/lxc.git
Source0: lxc-%version.tar
Source1: lxc-net.sysconfig
Source2: lxc-user-nic.control
Source3: lxc.watch

Patch2: 0002-FEDORA-lxc-net.service-wants-network-online.target.patch
Patch3: 0003-ALT-Fixed-_have-macro-in-bash-completion.patch
Patch4: 0004-ALT-tune-SysVinit-scripts.patch
Patch5: 0005-ALT-make-lxc-and-lxc-net-init-scripts-disabled-by-de.patch
Patch6: 0006-ALT-sysvinit-don-t-start-services-at-boot-by-default.patch

Requires: lxc-core lxc-net lxc-templates

# Automatically added by buildreq on Tue Aug 04 2020
# optimized out: docbook-dtds glibc-kernheaders-generic glibc-kernheaders-x86 libgpg-error perl perl-Encode perl-XML-LibXML perl-XML-SAX perl-XML-SAX-Base perl-parent pkg-config python-modules python2-base python3 python3-base sh4 xml-common xsltproc
BuildRequires: docbook2X libcap-devel libcap-devel-static libpam-devel libseccomp-devel libselinux-devel python3-dev

%description
Containers are insulated areas inside a system, which have their own namespace
for filesystem, network, PID, IPC, CPU and memory allocation and which can be
created using the Control Group and Namespace features included in the Linux
kernel.

This is meta package.

%package core
Summary: Core package for LXC
Group: System/Configuration/Other
Requires: rsync
Requires: service
%ifarch x86_64 aarch64 ppc64le
Requires: criu
%endif
Obsoletes: lxc-sysvinit

%package net
BuildArch: noarch
Summary: Network interface for LXC with DHCP
Group: System/Configuration/Networking
Requires: iproute2 dnsmasq lxc-core

%package templates
BuildArch: noarch
Summary: Templates for LXC
Group: System/Configuration/Other
Requires: lxc-core wget

%package -n liblxc%sover
Summary: LXC shared runtime library
Group: System/Libraries
Requires: lxc-runtime

%package runtime
Summary: Runtime files for LXC
Group: System/Configuration/Other
Provides: lxc-libs
Obsoletes: lxc-libs < %EVR
Requires(pre): /usr/sbin/groupadd

%package -n liblxc-devel
Summary: Development files for LXC
Group: Development/Other
Provides: lxc-devel

%set_pam_name pam_cgfs
%package -n %pam_name
Summary: %summary
Group: System/Base
BuildRequires(pre): libpam-devel

%description core
Containers are insulated areas inside a system, which have their own namespace
for filesystem, network, PID, IPC, CPU and memory allocation and which can be
created using the Control Group and Namespace features included in the Linux
kernel.

This package provides the lxc-* tools, which can be used to start a single
daemon in a container, or to boot an entire "containerized" system, and to
manage and debug your containers.

%description net
Containers are insulated areas inside a system, which have their own namespace
for filesystem, network, PID, IPC, CPU and memory allocation and which can be
created using the Control Group and Namespace features included in the Linux
kernel.

This package provides the network interface for containers with DHCP.

%description templates
Containers are insulated areas inside a system, which have their own namespace
for filesystem, network, PID, IPC, CPU and memory allocation and which can be
created using the Control Group and Namespace features included in the Linux
kernel.

This package contains templates for LXC.

%description -n liblxc%sover
Containers are insulated areas inside a system, which have their own namespace
for filesystem, network, PID, IPC, CPU and memory allocation and which can be
created using the Control Group and Namespace features included in the Linux
kernel.

This package contains runtime shared library for LXC.

%description runtime
Containers are insulated areas inside a system, which have their own namespace
for filesystem, network, PID, IPC, CPU and memory allocation and which can be
created using the Control Group and Namespace features included in the Linux
kernel.

This package contains runtime executables and data for LXC.

%description -n liblxc-devel
Containers are insulated areas inside a system, which have their own namespace
for filesystem, network, PID, IPC, CPU and memory allocation and which can be
created using the Control Group and Namespace features included in the Linux
kernel.

This package contains development files for LXC.

%description -n %pam_name
%summary
This package provides a Pluggable Authentication Module (PAM) to provide
logged-in users with a set of cgroups which they can administer.
This allows for instance unprivileged containers, and session
management using cgroup process tracking.

%prep
%setup
%autopatch -p1

%build
export bashcompdir="%_datadir/bash-completion/completions"
%autoreconf
%configure \
	--disable-werror \
	--disable-cgmanager \
	--disable-rpath \
	--disable-static \
	--enable-capabilities \
	--enable-pam \
	--enable-seccomp \
	--enable-selinux \
	--localstatedir=%_var \
	--with-config-path=%_var/lib/lxc \
	--with-distro=altlinux \
	--with-init-script=%{?_with_systemd:systemd,}sysvinit

%make_build

%install
%makeinstall_std

mkdir -p %buildroot%_localstatedir/lxc
install -pm644 %SOURCE1 %buildroot%_sysconfdir/sysconfig/lxc-net
install -pDm755 %SOURCE2 %buildroot%_controldir/lxc-user-nic

rm %buildroot%_datadir/lxc/lxc-patch.py

%post core
if [ $1 -eq 1 ]; then
	/sbin/chkconfig --add lxc ||:
fi

%preun core
if [ $1 -eq 0 ]; then
	/sbin/chkconfig --del lxc ||:
fi

%post net
if [ $1 -eq 1 ]; then
	/sbin/chkconfig --add lxc-net ||:
fi

%preun net
if [ $1 -eq 0 ]; then
	/sbin/chkconfig --del lxc-net ||:
fi

%pre runtime
groupadd -r -f vmusers ||:
%pre_control lxc-user-nic

%post runtime
%post_control -s vmusers lxc-user-nic

%files

%files core
%doc COPYING doc/FAQ.txt

%dir %_sysconfdir/lxc
%dir %_sysconfdir/sysconfig/lxc
%config(noreplace) %_sysconfdir/lxc/*
%config(noreplace) %_sysconfdir/sysconfig/lxc*

%dir %_datadir/bash-completion
%dir %_datadir/bash-completion/completions
%_datadir/bash-completion/completions/lxc

%_bindir/lxc-*
%_datadir/lxc/config
%_datadir/lxc/selinux

%dir %_defaultdocdir/lxc
%_defaultdocdir/lxc/examples

%_man1dir/lxc*
%_man5dir/lxc*
%_man7dir/lxc*

%dir %_mandir/ja
%dir %_mandir/ko
%_mandir/ja/*
%_mandir/ko/*

%_initdir/lxc

%if_with systemd
%_unitdir/lxc.service
%_unitdir/lxc@.service
%endif

%files net
%attr(555,root,root) %_libexecdir/lxc/lxc-net

%_initdir/lxc-net

%if_with systemd
%_unitdir/lxc-net.service
%endif

%files templates
%dir %_datadir/lxc
%_datadir/lxc/templates

%files -n liblxc%sover
%_libdir/liblxc.so.%sover
%_libdir/liblxc.so.%sover.*

%files runtime
%attr(4710,root,vmusers) %_libexecdir/lxc/lxc-user-nic
%attr(555,root,root) %_libexecdir/lxc/lxc-containers

%_libexecdir/lxc/lxc-apparmor-load
%_libexecdir/lxc/lxc-containers
%_libexecdir/lxc/lxc-monitord
%_libexecdir/lxc/hooks

%_controldir/lxc-user-nic
%_datadir/lxc/hooks
%_datadir/lxc/lxc.functions

%_sbindir/init.lxc
%_sbindir/init.lxc.static
%_localstatedir/lxc

%dir %_datadir/lxc
%dir %_libexecdir/lxc
%dir %_libdir/lxc
%dir %_libdir/lxc/rootfs
%_libdir/lxc/rootfs/README

%files -n liblxc-devel
%_includedir/lxc
%_libdir/liblxc.so
%_pkgconfigdir/lxc.pc

%files -n %pam_name
%_pam_modules_dir/*
%_man8dir/pam_cgfs.8*

%changelog
