%define modulename cherrypy

%def_with docs

Name: python3-module-%modulename
Version: 18.6.0
Release: alt1

Summary: CherryPy is a pythonic, object-oriented web development framework

License: BSD-3-Clause
Group: Development/Python3
URL: http://www.cherrypy.org
BuildArch: noarch

# git clone https://github.com/cherrypy/cherrypy
Source: %modulename-%version.tar
Patch: disable-codecov_button.patch

BuildRequires(pre): rpm-build-python3
%if_with docs
BuildRequires(pre): rpm-macros-sphinx3
BuildRequires: python3-module-setuptools
BuildRequires: python3-module-jaraco.collections
BuildRequires: python3-module-zc
BuildRequires: python3-module-zc.lockfile
BuildRequires: python3-module-portend
BuildRequires: python3-module-pytest
BuildRequires: python3-module-cheroot-tests
%endif
BuildRequires: python3-module-setuptools_scm
BuildRequires: python3-module-sphinx
BuildRequires: python3-module-rst.linker
BuildRequires: python3-module-jaraco.packaging
BuildRequires: python3-module-cheroot
BuildRequires: time

%add_python3_req_skip win32api
%add_python3_req_skip win32con
%add_python3_req_skip win32event
%add_python3_req_skip win32service
%add_python3_req_skip win32serviceutil
%add_python3_req_skip sqlobject

%description
Your CherryPy powered web applications are in fact stand-alone Python
applications embedding their own multi-threaded web server. You can deploy
them anywhere you can run Python applications. Apache is not required,
but it's possible to run a CherryPy application behind it.

%package tests
Summary: Tests for CherryPy
Group: Development/Python3
Requires: %name = %version-%release

%description tests
Your CherryPy powered web applications are in fact stand-alone Python
applications embedding their own multi-threaded web server. You can deploy
them anywhere you can run Python applications. Apache is not required,
but it's possible to run a CherryPy application behind it.

This package contains tests for CherryPy.

%package pickles
Summary: Pickles for CherryPy
Group: Development/Python3

%description pickles
Your CherryPy powered web applications are in fact stand-alone Python
applications embedding their own multi-threaded web server. You can deploy
them anywhere you can run Python applications. Apache is not required,
but it's possible to run a CherryPy application behind it.

This package contains pickles for CherryPy.

%package docs
Summary: Documentation for CherryPy
Group: Development/Documentation
BuildArch: noarch

%description docs
Your CherryPy powered web applications are in fact stand-alone Python
applications embedding their own multi-threaded web server. You can deploy
them anywhere you can run Python applications. Apache is not required,
but it's possible to run a CherryPy application behind it.

This package contains documentation for CherryPy.

%prep
%setup -n %modulename-%version
%patch -p1
sed -i "s/f'/'/;s/f\"/\"/" docs/conf.py

%if_with docs
%prepare_sphinx3 .
ln -s ../objects.inv docs/
%endif

%build
export SETUPTOOLS_SCM_PRETEND_VERSION=%version
subst 's|%_bindir/python|%_bindir/python3|' \
      cherrypy/process/servers.py cherrypy/test/sessiondemo.py
%python3_build

%install
export SETUPTOOLS_SCM_PRETEND_VERSION=%version
%python3_install
mv %buildroot%_bindir/cherryd %buildroot%_bindir/cherryd3

%if_with docs
export PYTHONPATH=$PWD
pushd docs
python3 /usr/bin/sphinx-build-3 -b html -d build/doctrees . build/html
python3 /usr/bin/sphinx-build-3 -b pickle -d build/doctrees . build/pickle
popd
%endif

%if_with docs
cp -fR docs/build/pickle %buildroot%python3_sitelibdir/%modulename/
%endif

%files
%doc cherrypy/tutorial
%_bindir/cherryd3
%python3_sitelibdir/*
%exclude %python3_sitelibdir/*/test
%if_with docs
%exclude %python3_sitelibdir/%modulename/pickle

%files pickles
%python3_sitelibdir/%modulename/pickle
%endif

%files tests
%python3_sitelibdir/*/test

%if_with docs
%files docs
%doc docs/build/html/*
%endif

%changelog
